"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createSynchronizationBuilder = exports.SynchronizationBuilder = void 0;
var _Operations = require("./Operations");
var _executeWithRetry = require("./executeWithRetry");
class SynchronizationBuilder {
  constructor(params) {
    this.timer = params.timer;
    this.context = params.context;
    this.operations = new _Operations.Operations();
  }
  insert(params) {
    return this.operations.insert(params);
  }
  modify(params) {
    return this.operations.modify(params);
  }
  delete(params) {
    return this.operations.delete(params);
  }
  build() {
    return async params => {
      if (this.operations.total === 0) {
        return;
      }
      await (0, _executeWithRetry.executeWithRetry)({
        ...params,
        maxRunningTime: this.timer.getRemainingMilliseconds(),
        timer: this.timer,
        context: this.context,
        operations: this.operations
      });
      this.operations.clear();
    };
  }
}
exports.SynchronizationBuilder = SynchronizationBuilder;
const createSynchronizationBuilder = params => {
  return new SynchronizationBuilder(params);
};
exports.createSynchronizationBuilder = createSynchronizationBuilder;

//# sourceMappingURL=SynchronizationBuilder.js.map