"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createEventHandler = void 0;
var _handlerAws = require("@webiny/handler-aws");
var _Decompressor = require("./Decompressor");
var _OperationsBuilder = require("./OperationsBuilder");
var _executeWithRetry = require("./executeWithRetry");
/**
 * Also, we need to set the maximum running time for the Lambda Function.
 * https://github.com/webiny/webiny-js/blob/f7352d418da2b5ae0b781376be46785aa7ac6ae0/packages/pulumi-aws/src/apps/core/CoreOpenSearch.ts#L232
 * https://github.com/webiny/webiny-js/blob/f7352d418da2b5ae0b781376be46785aa7ac6ae0/packages/pulumi-aws/src/apps/core/CoreElasticSearch.ts#L218
 */
const MAX_RUNNING_TIME = 900;
const createEventHandler = () => {
  return (0, _handlerAws.createDynamoDBEventHandler)(async ({
    event,
    context: ctx,
    lambdaContext
  }) => {
    const timer = (0, _handlerAws.timerFactory)(lambdaContext);
    const context = ctx;
    if (!context.elasticsearch) {
      console.error("Missing elasticsearch definition on context.");
      return null;
    }
    const decompressor = new _Decompressor.Decompressor({
      plugins: context.plugins
    });
    const builder = new _OperationsBuilder.OperationsBuilder({
      decompressor
    });
    const operations = await builder.build({
      records: event.Records
    });
    /**
     * No need to do anything if there are no operations.
     */
    if (operations.total === 0) {
      return null;
    }
    /**
     * Execute the operations with retry.
     */
    await (0, _executeWithRetry.executeWithRetry)({
      timer,
      maxRunningTime: MAX_RUNNING_TIME,
      context,
      operations
    });
    return null;
  });
};
exports.createEventHandler = createEventHandler;

//# sourceMappingURL=eventHandler.js.map