"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.executeWithRetry = void 0;
var _execute = require("./execute");
var _NotEnoughRemainingTimeError = require("./NotEnoughRemainingTimeError");
var _pRetry = _interopRequireDefault(require("p-retry"));
var _getNumberEnvVariable = require("./helpers/getNumberEnvVariable");
const minRemainingSecondsToTimeout = 120;
const MAX_PROCESSOR_PERCENT = (0, _getNumberEnvVariable.getNumberEnvVariable)("MAX_ES_PROCESSOR", process.env.NODE_ENV === "test" ? 101 : 98);
const executeWithRetry = async params => {
  const maxRetryTime = (0, _getNumberEnvVariable.getNumberEnvVariable)("WEBINY_DYNAMODB_TO_ELASTICSEARCH_MAX_RETRY_TIME", params.maxRetryTime || 300000);
  const retries = (0, _getNumberEnvVariable.getNumberEnvVariable)("WEBINY_DYNAMODB_TO_ELASTICSEARCH_RETRIES", params.retries || 20);
  const minTimeout = (0, _getNumberEnvVariable.getNumberEnvVariable)("WEBINY_DYNAMODB_TO_ELASTICSEARCH_MIN_TIMEOUT", params.minTimeout || 1500);
  const maxTimeout = (0, _getNumberEnvVariable.getNumberEnvVariable)("WEBINY_DYNAMODB_TO_ELASTICSEARCH_MAX_TIMEOUT", params.maxTimeout || 30000);
  try {
    await (0, _pRetry.default)((0, _execute.execute)({
      timer: params.timer,
      maxRunningTime: params.maxRunningTime,
      maxProcessorPercent: params.maxProcessorPercent || MAX_PROCESSOR_PERCENT,
      context: params.context,
      operations: params.operations
    }), {
      maxRetryTime,
      retries,
      minTimeout,
      maxTimeout,
      onFailedAttempt: error => {
        if (params.timer.getRemainingSeconds() < minRemainingSecondsToTimeout) {
          throw new _NotEnoughRemainingTimeError.NotEnoughRemainingTimeError(error);
        }
        /**
         * We will only log attempts which are after 3/4 of total attempts.
         */
        if (error.attemptNumber < retries * 0.75) {
          return;
        }
        console.error(`Attempt #${error.attemptNumber} failed.`);
        console.error(error);
      }
    });
  } catch (ex) {
    // TODO implement storing of failed operations
    throw ex;
  }
};
exports.executeWithRetry = executeWithRetry;

//# sourceMappingURL=executeWithRetry.js.map